==> ejc-zjkjcost-impl-3.0.0-20220628.083136-18-sources.jar: com/ejianc/business/zjkjcost/reserve/bean/DepartmentApproveEntity.java <==
package com.ejianc.business.zjkjcost.reserve.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 风险预留金-项目部预留金返还审批表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_reserve_department_approve")
public class DepartmentApproveEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编号
    @TableField(value="org_id")
    private Long orgId; // 项目部
    @TableField(value="org_name")
    private String orgName; // 项目部名称
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 组织
    @TableField(value="parent_org_name")
    private String parentOrgName; // 组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 组织组织编码
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="employee_time")
    private Date employeeTime; // 经办时间
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="reserve_mny")
    private BigDecimal reserveMny; // 预留风险金额
    @TableField(value="apply_restitution_ratio")
    private BigDecimal applyRestitutionRatio; // 申请预留返还比例(项目部)
    @TableField(value="specific_clause")
    private String specificClause; // 具体事项(项目部)
    @TableField(value="verify_total_mny")
    private BigDecimal verifyTotalMny; // 预留风险金核定总额（财务部）
    @TableField(value="actual_reserve_mny")
    private BigDecimal actualReserveMny; // 实际预留风险金额(财务部)
    @TableField(value="finance_restitution_mny")
    private BigDecimal financeRestitutionMny; // 返还金额(财务部)
    @TableField(value="business_restitution_ratio")
    private BigDecimal businessRestitutionRatio; // 建议返还预留比例(商务部)
    @TableField(value="business_restitution_mny")
    private BigDecimal businessRestitutionMny; // 建议返还预留金额(商务部)
    @TableField(value="economy_restitution_mny")
    private BigDecimal economyRestitutionMny; // 返还金额(经济部)
    @TableField(value="general_restitution_mny")
    private BigDecimal generalRestitutionMny; // 返还金额(总经理)
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Date getEmployeeTime() {
        return employeeTime;
    }

    public void setEmployeeTime(Date employeeTime) {
        this.employeeTime = employeeTime;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public BigDecimal getReserveMny() {
        return reserveMny;
    }

    public void setReserveMny(BigDecimal reserveMny) {
        this.reserveMny = reserveMny;
    }
    public BigDecimal getApplyRestitutionRatio() {
        return applyRestitutionRatio;
    }

    public void setApplyRestitutionRatio(BigDecimal applyRestitutionRatio) {
        this.applyRestitutionRatio = applyRestitutionRatio;
    }
    public String getSpecificClause() {
        return specificClause;
    }

    public void setSpecificClause(String specificClause) {
        this.specificClause = specificClause;
    }
    public BigDecimal getVerifyTotalMny() {
        return verifyTotalMny;
    }

    public void setVerifyTotalMny(BigDecimal verifyTotalMny) {
        this.verifyTotalMny = verifyTotalMny;
    }
    public BigDecimal getActualReserveMny() {
        return actualReserveMny;
    }

    public void setActualReserveMny(BigDecimal actualReserveMny) {
        this.actualReserveMny = actualReserveMny;
    }
    public BigDecimal getFinanceRestitutionMny() {
        return financeRestitutionMny;
    }

    public void setFinanceRestitutionMny(BigDecimal financeRestitutionMny) {
        this.financeRestitutionMny = financeRestitutionMny;
    }
    public BigDecimal getBusinessRestitutionRatio() {
        return businessRestitutionRatio;
    }

    public void setBusinessRestitutionRatio(BigDecimal businessRestitutionRatio) {
        this.businessRestitutionRatio = businessRestitutionRatio;
    }
    public BigDecimal getBusinessRestitutionMny() {
        return businessRestitutionMny;
    }

    public void setBusinessRestitutionMny(BigDecimal businessRestitutionMny) {
        this.businessRestitutionMny = businessRestitutionMny;
    }
    public BigDecimal getEconomyRestitutionMny() {
        return economyRestitutionMny;
    }

    public void setEconomyRestitutionMny(BigDecimal economyRestitutionMny) {
        this.economyRestitutionMny = economyRestitutionMny;
    }
    public BigDecimal getGeneralRestitutionMny() {
        return generalRestitutionMny;
    }

    public void setGeneralRestitutionMny(BigDecimal generalRestitutionMny) {
        this.generalRestitutionMny = generalRestitutionMny;
    }
    
}

==> ejc-zjkjcost-impl-3.0.0-20230415.031502-129-sources.jar: com/ejianc/business/zjkjcost/reserve/bean/DepartmentApproveEntity.java <==
package com.ejianc.business.zjkjcost.reserve.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 风险预留金-项目部预留金返还审批表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_reserve_department_approve")
public class DepartmentApproveEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编号
    @TableField(value="org_id")
    private Long orgId; // 项目部
    @TableField(value="org_name")
    private String orgName; // 项目部名称
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 组织
    @TableField(value="parent_org_name")
    private String parentOrgName; // 组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 组织组织编码
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="employee_time")
    private Date employeeTime; // 经办时间
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="reserve_mny")
    private BigDecimal reserveMny; // 预留风险金额
    @TableField(value="apply_restitution_ratio")
    private BigDecimal applyRestitutionRatio; // 申请预留返还比例(项目部)
    @TableField(value="specific_clause")
    private String specificClause; // 具体事项(项目部)
    @TableField(value="verify_total_mny")
    private BigDecimal verifyTotalMny; // 预留风险金核定总额（财务部）
    @TableField(value="actual_reserve_mny")
    private BigDecimal actualReserveMny; // 实际预留风险金额(财务部)
    @TableField(value="finance_restitution_mny")
    private BigDecimal financeRestitutionMny; // 返还金额(财务部)
    @TableField(value="business_restitution_ratio")
    private BigDecimal businessRestitutionRatio; // 建议返还预留比例(商务部)
    @TableField(value="business_restitution_mny")
    private BigDecimal businessRestitutionMny; // 建议返还预留金额(商务部)
    @TableField(value="economy_restitution_mny")
    private BigDecimal economyRestitutionMny; // 返还金额(经济部)
    @TableField(value="general_restitution_mny")
    private BigDecimal generalRestitutionMny; // 返还金额(总经理)
    @TableField(value="source_id")
    private Long sourceId; // 来源ID


    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Date getEmployeeTime() {
        return employeeTime;
    }

    public void setEmployeeTime(Date employeeTime) {
        this.employeeTime = employeeTime;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public BigDecimal getReserveMny() {
        return reserveMny;
    }

    public void setReserveMny(BigDecimal reserveMny) {
        this.reserveMny = reserveMny;
    }
    public BigDecimal getApplyRestitutionRatio() {
        return applyRestitutionRatio;
    }

    public void setApplyRestitutionRatio(BigDecimal applyRestitutionRatio) {
        this.applyRestitutionRatio = applyRestitutionRatio;
    }
    public String getSpecificClause() {
        return specificClause;
    }

    public void setSpecificClause(String specificClause) {
        this.specificClause = specificClause;
    }
    public BigDecimal getVerifyTotalMny() {
        return verifyTotalMny;
    }

    public void setVerifyTotalMny(BigDecimal verifyTotalMny) {
        this.verifyTotalMny = verifyTotalMny;
    }
    public BigDecimal getActualReserveMny() {
        return actualReserveMny;
    }

    public void setActualReserveMny(BigDecimal actualReserveMny) {
        this.actualReserveMny = actualReserveMny;
    }
    public BigDecimal getFinanceRestitutionMny() {
        return financeRestitutionMny;
    }

    public void setFinanceRestitutionMny(BigDecimal financeRestitutionMny) {
        this.financeRestitutionMny = financeRestitutionMny;
    }
    public BigDecimal getBusinessRestitutionRatio() {
        return businessRestitutionRatio;
    }

    public void setBusinessRestitutionRatio(BigDecimal businessRestitutionRatio) {
        this.businessRestitutionRatio = businessRestitutionRatio;
    }
    public BigDecimal getBusinessRestitutionMny() {
        return businessRestitutionMny;
    }

    public void setBusinessRestitutionMny(BigDecimal businessRestitutionMny) {
        this.businessRestitutionMny = businessRestitutionMny;
    }
    public BigDecimal getEconomyRestitutionMny() {
        return economyRestitutionMny;
    }

    public void setEconomyRestitutionMny(BigDecimal economyRestitutionMny) {
        this.economyRestitutionMny = economyRestitutionMny;
    }
    public BigDecimal getGeneralRestitutionMny() {
        return generalRestitutionMny;
    }

    public void setGeneralRestitutionMny(BigDecimal generalRestitutionMny) {
        this.generalRestitutionMny = generalRestitutionMny;
    }
    
}
